@@ -1,11 +1,11 @@
 #
-# $Id: Onyphe.pm,v 70c24256e451 2025/03/05 16:13:54 gomor $
+# $Id: Onyphe.pm,v d8b98095b893 2023/08/30 05:24:07 gomor $
 #
 package Onyphe;
 use strict;
 use warnings;
 
-our $VERSION = '4.19.0';
+our $VERSION = '4.10';
 
 use experimental qw(signatures);
 
@@ -42,7 +42,6 @@ sub init ($self, $file = undef) {
    $config->{''}{api_keepalive} ||= 0;
    $config->{''}{api_endpoint} ||= 'https://www.onyphe.io/api/v2';
    $config->{''}{api_ondemand_endpoint} ||= $config->{''}{api_endpoint};
-   $config->{''}{api_asd_endpoint} ||= $config->{''}{api_endpoint};
 
    if ($self->verbose) {
       for my $k (keys %{$config->{''}}) {
@@ -69,7 +68,7 @@ Onyphe - ONYPHE base class
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2025, ONYPHE SAS
+Copyright (c) 2023, ONYPHE
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
