@@ -1,11 +1,11 @@
 #
-# $Id: Api.pm,v 184b7baee9fd 2025/03/14 14:27:03 gomor $
+# $Id: Api.pm,v d8b98095b893 2023/08/30 05:24:07 gomor $
 #
 package Onyphe::Api;
 use strict;
 use warnings;
 
-our $VERSION = '4.19.0';
+our $VERSION = '4.10';
 
 use experimental qw(signatures);
 
@@ -15,11 +15,11 @@ our @AS = qw(endpoint apikey username password);
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
 __PACKAGE__->cgBuildIndices;
 
-#use utf8;
+use utf8;
 use File::Temp qw(tempfile);
 use File::Slurp qw(read_file);
 use Mojo::URL;
-use JSON::XS qw(encode_json decode_json);
+use JSON::XS qw(encode_json);
 use Mojo::UserAgent;
 use Mojo::Util qw(b64_encode url_escape);
 
@@ -66,11 +66,6 @@ sub _headers ($self, $apikey, $ct = undef) {
    return $headers;
 }
 
-sub get_total ($self, $json) {
-   my $total = $json->{total};
-   return defined($total) && $total ? $total : 0;
-}
-
 sub get_maxpage ($self, $json) {
    my $maxpage = $json->{max_page};
    return defined($maxpage) && $maxpage ? $maxpage : 0;
@@ -128,9 +123,6 @@ sub request ($self, $api, $input = undef, $page = undef, $maxpage = undef, $para
       || $self->endpoint;
    my $apikey = $global->{api_key} || $self->apikey;
 
-   die("FATAL: api_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
    # Use default callback when none given:
    $cb ||= $self->_cb_request;
 
@@ -175,13 +167,7 @@ sub request ($self, $api, $input = undef, $page = undef, $maxpage = undef, $para
       }
       unless ($res->is_success) {
          my $code = $res->code;
-         # Not JSON result:
-         unless (defined($res->json)) {
-            my $text = $res->message;
-            print STDERR "ERROR: Request API call failed: $code, $text\n";
-            return;
-         }
-         my $json = $res->json;
+         my $text = $res->json->{text};
          # If code 429, retry with some sleep:
          if ($code == 429) {
             print STDERR "WARNING: Too fast, sleeping before retry...\n" unless $self->silent;
@@ -189,20 +175,11 @@ sub request ($self, $api, $input = undef, $page = undef, $maxpage = undef, $para
             goto RETRY;
          }
          # Otherwise, stops and display error:
-         print STDERR "ERROR: Request API call failed: $code, ".encode_json($json)."\n"
-            unless $self->silent;
+         print STDERR "ERROR: Request API call failed: $code, $text\n" unless $self->silent;
          return;
       }
 
       my $json = $res->json;
-
-      # When asking for a count only, display and stop:
-      if (defined($params) && $params->{count}) {
-         my $total = $self->get_total($json);
-         $cb->([{ "total" => $total } ], $cb_args);
-         return 1;
-      }
-
       # Fetch max_page value so we can iterate:
       $this_max_page = $self->get_maxpage($json) unless defined $this_max_page;
       if (defined($input) && !$this_max_page) {
@@ -238,9 +215,6 @@ sub post_request ($self, $api, $input = undef, $page = undef, $maxpage = undef,
       || $self->endpoint;
    my $apikey = $global->{api_key} || $self->apikey;
 
-   die("FATAL: api_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
    # Use default callback when none given:
    $cb ||= $self->_cb_request;
 
@@ -272,6 +246,8 @@ sub post_request ($self, $api, $input = undef, $page = undef, $maxpage = undef,
 
       print STDERR "VERBOSE: Calling API: $path\n" if $self->verbose;
 
+      $input = url_escape($input) if defined $input;
+
    RETRY:
       my $res;
       eval {
@@ -284,13 +260,7 @@ sub post_request ($self, $api, $input = undef, $page = undef, $maxpage = undef,
       }
       unless ($res->is_success) {
          my $code = $res->code;
-         # Not JSON result:
-         unless (defined($res->json)) {
-            my $text = $res->message;
-            print STDERR "ERROR: Request API call failed: $code, $text\n";
-            return;
-         }
-         my $json = $res->json;
+         my $text = $res->json->{text};
          # If code 429, retry with some sleep:
          if ($code == 429) {
             print STDERR "WARNING: Too fast, sleeping before retry...\n" unless $self->silent;
@@ -298,8 +268,7 @@ sub post_request ($self, $api, $input = undef, $page = undef, $maxpage = undef,
             goto RETRY;
          }
          # Otherwise, stops and display error:
-         print STDERR "ERROR: Request API call failed: $code, ".encode_json($json)."\n"
-            unless $self->silent;
+         print STDERR "ERROR: Request API call failed: $code, $text\n" unless $self->silent;
          return;
       }
 
@@ -380,14 +349,11 @@ sub _cb_stream ($self, $results = undef, $cb_args = undef) {
 }
 
 sub _on_read ($self, $cb = undef, $cb_args = undef, $buf = \'') {
+   # XXX: handle is_success and render ERROR
    return sub {
       my ($content, $bytes) = @_;
       $bytes = $$buf.$bytes;  # Complete from previously incomplete lines
       my ($this, $tail) = $bytes =~ m/^(.*\n)(.*)$/s;
-      # Check errors:
-      if (defined($bytes) && $bytes =~ m{"status":"nok"}) {
-         return $cb->($bytes, $cb_args);
-      }
       # One line is not complete, add to buf and go to next:
       if (!defined($this)) {
          $buf = \$bytes;
@@ -408,23 +374,15 @@ sub stream ($self, $method, $api, $input, $params = undef, $cb = undef, $cb_args
       || $self->endpoint;
    my $apikey = $global->{api_key} || $self->apikey;
 
-   die("FATAL: api_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
    # Use default callback when none given:
    $cb ||= $self->_cb_stream;
 
    my $ua = $self->_ua();
    my $headers = $self->_headers($apikey);
-   if ($method eq 'POST') {
-      $headers = $self->_headers($apikey, 'application/x-www-form-urlencoded');
-   }
 
    my $path = $endpoint.$api;
    unless (-f $input) {
-      if ($method eq 'GET') {
-         $path .= '/'.url_escape($input);   # Build with OQL string
-      }
+      $path .= '/'.url_escape($input);   # Build with OQL string
    }
 
    my $p= [];
@@ -446,13 +404,7 @@ sub stream ($self, $method, $api, $input, $params = undef, $cb = undef, $cb_args
    my $url = Mojo::URL->new($path);
 
    my $buf = '';  # Will store incomplete lines for later processing
-   my $tx;
-   if ($method eq 'GET') {
-      $tx = $ua->build_tx($method => $url => $headers);
-   }
-   elsif ($method eq 'POST') {
-      $tx = $ua->build_tx($method => $url => $headers => form => { query => $input });
-   }
+   my $tx = $ua->build_tx($method => $url => $headers);
    # Replace "read" events to disable default content parser:
    $tx->res->content->unsubscribe('read')->on(read => $self->_on_read($cb, $cb_args, \$buf));
 
@@ -471,9 +423,6 @@ sub post_stream ($self, $method, $api, $input, $params = undef, $cb = undef, $cb
       || $self->endpoint;
    my $apikey = $global->{api_key} || $self->apikey;
 
-   die("FATAL: api_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
    # Use default callback when none given:
    $cb ||= $self->_cb_stream;
 
@@ -481,8 +430,9 @@ sub post_stream ($self, $method, $api, $input, $params = undef, $cb = undef, $cb
    my $headers = $self->_headers($apikey, 'application/x-www-form-urlencoded');
 
    my $path = $endpoint.$api;
+   $input = url_escape($input);   # Build with OQL string
 
-   my $p = [];
+   my $p= [];
    push @$p, { k => 'k', v => $apikey };
    push @$p, { k => 'trackquery', v => 'true' } if $global->{api_trackquery};
    push @$p, { k => 'calculated', v => 'true' } if $global->{api_calculated};
@@ -563,7 +513,7 @@ sub bulk_discovery ($self, $api, $file, $oql = undef, $params = undef, $cb = und
       for (@lines) {
          chomp;
          my $line = "$_ $oql";
-         #utf8::encode($line);  # Not required, already in UTF-8
+         utf8::encode($line);
          print $fh "$line\n";
       }
       close($fh);
@@ -600,9 +550,6 @@ sub alert ($self, $method, $api, $name, $oql, $email, $threshold = 0, $cb = unde
       || $self->endpoint;
    my $apikey = $global->{api_key} || $self->apikey;
 
-   die("FATAL: api_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
    # Use default callback when none given:
    $cb ||= $self->_cb_alert;
 
@@ -641,13 +588,7 @@ RETRY:
    }
    unless ($res->is_success) {
       my $code = $res->code;
-      # Not JSON result:
-      unless (defined($res->json)) {
-         my $text = $res->message;
-         print STDERR "ERROR: Alert API call failed: $code, $text\n";
-         return;
-      }
-      my $json = $res->json;
+      my $text = $res->json->{text};
       # If code 429, retry with some sleep:
       if ($code == 429) {
          print STDERR "WARNING: Too fast, sleeping before retry...\n" unless $self->silent;
@@ -655,8 +596,7 @@ RETRY:
          goto RETRY;
       }
       # Otherwise, stops and display error:
-      print STDERR "ERROR: Alert API call failed: $code, ".encode_json($json)."\n"
-         unless $self->silent;
+      print STDERR "ERROR: Alert API call failed: $code, $text\n" unless $self->silent;
       return;
    }
 
@@ -704,9 +644,6 @@ sub ondemand ($self, $method, $api, $param, $post, $cb = undef, $cb_args = undef
    my $endpoint = $global->{api_ondemand_endpoint} || $self->endpoint;
    my $apikey = $global->{api_ondemand_key} || $self->apikey;
 
-   die("FATAL: api_ondemand_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_ondemand_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
    # Use default callback when none given:
    $cb ||= $self->_cb_ondemand;
 
@@ -720,15 +657,9 @@ sub ondemand ($self, $method, $api, $param, $post, $cb = undef, $cb_args = undef
 
    if (defined($param)) {
       $post->{maxscantime} = $param->{maxscantime} if defined $param->{maxscantime};
-      $post->{aslines} = $param->{aslines} ? 'true' : 'false' if defined $param->{aslines};
-      $post->{aslink} = $param->{aslink} ? 'true' : 'false' if defined $param->{aslink};
-      $post->{full} = $param->{full} ? 'true' : 'false' if defined $param->{full};
       $post->{urlscan} = $param->{urlscan} ? 'true' : 'false' if defined $param->{urlscan};
       $post->{vulnscan} = $param->{vulnscan} ? 'true' : 'false' if defined $param->{vulnscan};
-      $post->{riskscan} = $param->{riskscan} ? 'true' : 'false' if defined $param->{riskscan};
-      $post->{asm} = $param->{asm} ? 'true' : 'false' if defined $param->{asm};
       $post->{import} = $param->{import} ? 'true' : 'false' if defined $param->{import};
-      $post->{ports} = $param->{ports} if defined $param->{ports};
    }
 
    print STDERR "VERBOSE: Calling API: $path\n" if $self->verbose;
@@ -752,14 +683,8 @@ RETRY:
    }
    unless ($res->is_success) {
       my $code = $res->code;
-      # Not JSON result:
-      unless (defined($res->json)) {
-         my $text = $res->message;
-         print STDERR "ERROR: Request API call failed: $code, $text\n";
-         return;
-      }
       #print Data::Dumper::Dumper($res->body)."\n";
-      my $json = $res->json;
+      my $text = $res->json->{text};
       # If code 429, retry with some sleep:
       if ($code == 429) {
          print STDERR "WARNING: Too fast, sleeping before retry...\n" unless $self->silent;
@@ -767,20 +692,12 @@ RETRY:
          goto RETRY;
       }
       # Otherwise, stops and display error:
-      print STDERR "ERROR: Ondemand API call failed: $code, ".encode_json($json)."\n"
-         unless $self->silent;
+      print STDERR "ERROR: Ondemand API call failed: $code, $text\n" unless $self->silent;
       return;
    }
 
-   my $data;
-   if (defined($param) && $param->{aslines}) {
-      my @lines = split(/\r?\n/, $res->body);
-      $data = \@lines;
-   }
-   else {
-      $data = $res->json;
-   }
-   $cb->($data, $cb_args);
+   my $json = $res->json;
+   $cb->($json, $cb_args);
 
    return 1;
 }
@@ -789,18 +706,10 @@ sub ondemand_scope_ip ($self, $target, $param = undef, $cb = undef, $cb_args = u
    return $self->ondemand('post', '/ondemand/scope/ip/single', $param, { ip => $target }, $cb, $cb_args);
 }
 
-sub ondemand_scope_port ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->ondemand('post', '/ondemand/scope/port/single', $param, { port => $target }, $cb, $cb_args);
-}
-
 sub ondemand_scope_domain ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
    return $self->ondemand('post', '/ondemand/scope/domain/single', $param, { domain => $target }, $cb, $cb_args);
 }
 
-sub ondemand_scope_hostname ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->ondemand('post', '/ondemand/scope/hostname/single', $param, { hostname => $target }, $cb, $cb_args);
-}
-
 sub ondemand_scope_ip_bulk ($self, $file, $param = undef, $cb = undef, $cb_args = undef) {
    if (! -f $file) {
       print STDERR "ERROR: Ondemand Scope Ip Bulk needs a file as input\n"
@@ -837,24 +746,6 @@ sub ondemand_scope_domain_bulk ($self, $file, $param = undef, $cb = undef, $cb_a
    return $self->ondemand('post', '/ondemand/scope/domain/bulk', $param, { domain => $target }, $cb, $cb_args);
 }
 
-sub ondemand_scope_hostname_bulk ($self, $file, $param = undef, $cb = undef, $cb_args = undef) {
-   if (! -f $file) {
-      print STDERR "ERROR: Ondemand Scope Hostname Bulk needs a file as input\n"
-         unless $self->silent;
-   }
-
-   my @lines = read_file($file);
-   for (@lines) { chomp };
-   unless (@lines) {
-      print STDERR "ERROR: Ondemand Scope Hostname Bulk needs a file with content\n"
-         unless $self->silent;
-   }
-
-   my $target = join(',', @lines);
-
-   return $self->ondemand('post', '/ondemand/scope/hostname/bulk', $param, { hostname => $target }, $cb, $cb_args);
-}
-
 sub ondemand_scope_result ($self, $scan_id, $param = undef, $cb = undef, $cb_args = undef) {
    return $self->ondemand('get', '/ondemand/scope/result/'.$scan_id, $param, undef, $cb, $cb_args);
 }
@@ -867,24 +758,6 @@ sub ondemand_resolver_domain ($self, $target, $param = undef, $cb = undef, $cb_a
    return $self->ondemand('post', '/ondemand/resolver/domain/single', $param, { domain => $target }, $cb, $cb_args);
 }
 
-sub ondemand_resolver_domain_bulk ($self, $file, $param = undef, $cb = undef, $cb_args = undef) {
-   if (! -f $file) {
-      print STDERR "ERROR: Ondemand Resolver Domain Bulk needs a file as input\n"
-         unless $self->silent;
-   }
-
-   my @lines = read_file($file);
-   for (@lines) { chomp };
-   unless (@lines) {
-      print STDERR "ERROR: Ondemand Resolver Domain Bulk needs a file with content\n"
-         unless $self->silent;
-   }
-
-   my $target = join(',', @lines);
-
-   return $self->ondemand('post', '/ondemand/resolver/domain/bulk', $param, { domain => $target }, $cb, $cb_args);
-}
-
 sub ondemand_resolver_hostname ($self, $target, $param = undef, $cb = undef, $cb_args = undef) {
    return $self->ondemand('post', '/ondemand/resolver/hostname/single', $param, { hostname => $target }, $cb, $cb_args);
 }
@@ -893,274 +766,6 @@ sub ondemand_resolver_result ($self, $scan_id, $param = undef, $cb = undef, $cb_
    return $self->ondemand('get', '/ondemand/resolver/result/'.$scan_id, $param, undef, $cb, $cb_args);
 }
 
-#
-# ASD APIs:
-#
-sub _cb_asd ($self, $results = undef, $cb_args = undef) {
-   return sub ($results, $cb_args) {
-      $results = ref($results) eq 'ARRAY' ? $results : [ $results ];
-      for (@$results) {
-         print $self->encode($_)."\n";
-      }
-   };
-}
-
-sub asd ($self, $method, $api, $param, $post, $cb = undef, $cb_args = undef) {
-   my $global = $self->config->{''};
-   my $endpoint = $global->{api_asd_endpoint} || $self->endpoint;
-   my $apikey = $global->{api_asd_key} || $self->apikey;
-
-   die("FATAL: api_asd_key not configured in ~/.onyphe.ini\n") unless defined($apikey);
-   die("FATAL: api_asd_endpoint not configured in ~/.onyphe.ini\n") unless defined($endpoint);
-
-   # Use default callback when none given:
-   $cb ||= $self->_cb_asd;
-
-   my $ua = $self->_ua();
-   my $headers = $self->_headers($apikey);
-
-   $api =~ s{^/*}{/}g;
-
-   my $path = $endpoint.$api;
-   $path .= '?k='.$apikey;
-
-   if (defined($param)) {
-      $post->{domain} = $param->{domain} if defined $param->{domain};
-      $post->{aslines} = $param->{aslines} ? 'true' : 'false' if defined $param->{aslines};
-      $post->{astask} = $param->{astask} ? 'true' : 'false' if defined $param->{astask};
-      $post->{trusted} = $param->{trusted} ? 'true' : 'false' if defined $param->{trusted};
-      $post->{field} = $param->{field} if defined $param->{field};
-      $post->{query} = $param->{query} if defined $param->{query};
-      $post->{includep} = $self->_load_file($param->{includep})
-         if defined($param->{includep});
-      $post->{excludep} = $self->_load_file($param->{excludep})
-         if defined($param->{excludep});
-   }
-
-   print STDERR "VERBOSE: Calling API: $path\n" if $self->verbose;
-   print STDERR "VERBOSE: Calling API with content: ".Data::Dumper::Dumper($post)."\n"
-      if $self->verbose;
-
-   my $url = Mojo::URL->new($path);
-
-   my @args = ( $url => $headers );
-   @args = ( $url => $headers => json => $post ) if defined $post;
-
-   #print STDERR "DEBUG: args: ".Data::Dumper::Dumper(\@args)."\n";
-
-RETRY:
-   my $res;
-   eval {
-      $res = $ua->$method(@args)->result;
-   };
-   if ($@) {
-      chomp($@);
-      if ($@ =~ m{Premature connection close}i) {
-         return 1;
-      }
-      print STDERR "WARNING: ASD API call failed: [$@], retrying...\n" unless $self->silent;
-      goto RETRY;
-   }
-   unless ($res->is_success) {
-      my $code = $res->code;
-      # Not JSON result:
-      unless (defined($res->json)) {
-         my $text = $res->message;
-         print STDERR "ERROR: ASD API call failed: $code, $text\n";
-         return;
-      }
-      #print Data::Dumper::Dumper($res->body)."\n";
-      my $json = $res->json;
-      # If code 429, retry with some sleep:
-      if ($code == 429) {
-         print STDERR "WARNING: Too fast, sleeping before retry...\n" unless $self->silent;
-         sleep 1;
-         goto RETRY;
-      }
-      # Otherwise, stops and display error:
-      print STDERR "ERROR: ASD API call failed: $code, ".encode_json($json)."\n"
-         unless $self->silent;
-      return;
-   }
-
-   my $data;
-   if (defined($param) && $param->{aslines}) {
-      my @lines = split(/\r?\n/, $res->body);
-      $data = \@lines;
-   }
-   else {
-      $data = $res->json;
-   }
-   $cb->($data, $cb_args);
-
-   return 1;
-}
-
-sub _load_file ($self, $arg) {
-   if (-f $arg) {  # If its a file, we create the list of values to push
-      my $docs = $self->asd_load_input($arg);
-      unless (defined($docs) && @$docs) {
-         print STDERR "VERBOSE: asd_load_input: failed from bad content or empty content\n";
-         return;
-      }
-      $arg = $docs;
-   }
-   else {
-      $arg = [ split(',', $arg) ];
-   }
-
-   return $arg;
-}
-
-sub _arg_from_field ($self, $arg, $field) {
-   return $arg if ref($arg) eq 'ARRAY' && !ref($arg->[0]);
-   my $values = [];
-   for (@$arg) {
-      next unless defined($_->{$field});
-      push @$values, $_->{$field};
-   }
-   return $values;
-}
-
-sub asd_pivot_query ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->asd('post', '/asd/pivot/query', $param, { query => $arg }, $cb, $cb_args);
-}
-
-sub asd_domain_tld ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/domain/tld', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_dns_domain_ns ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/dns/domain/ns', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_dns_domain_mx ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/dns/domain/mx', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_certso_domain ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/certso/domain', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_certso_wildcard ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'subject.organization');
-   return $self->asd('post', '/asd/certso/wildcard', $param, { certso => $arg }, $cb, $cb_args);
-}
-
-sub _arg_from_inventory ($self, $arg, $default) {
-   return { $default => $arg } if ref($arg) eq 'ARRAY' && !ref($arg->[0]);
-   my $values = {};
-   for my $doc (@$arg) {
-      for my $field (keys %$doc) {
-         next unless defined($doc->{$field});
-         push @{$values->{$field}}, $doc->{$field};
-      }
-   }
-   return $values;
-}
-
-sub asd_org_inventory ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_inventory($arg, 'domain');
-   return $self->asd('post', '/asd/org/inventory', $param, { inventory => $arg }, $cb, $cb_args);
-}
-
-sub asd_ip_inventory ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_inventory($arg, 'domain');
-   return $self->asd('post', '/asd/ip/inventory', $param, { inventory => $arg }, $cb, $cb_args);
-}
-
-sub asd_subnet_inventory ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_inventory($arg, 'domain');
-   return $self->asd('post', '/asd/subnet/inventory', $param, { inventory => $arg }, $cb, $cb_args);
-}
-
-sub asd_vhost_inventory ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_inventory($arg, 'domain');
-   return $self->asd('post', '/asd/vhost/inventory', $param, { inventory => $arg }, $cb, $cb_args);
-}
-
-sub asd_score_inventory ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_inventory($arg, 'domain');
-   return $self->asd('post', '/asd/score/inventory', $param, { inventory => $arg }, $cb, $cb_args);
-}
-
-sub asd_dns_domain_soa ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/dns/domain/soa', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_domain_wildcard ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/domain/wildcard', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_domain_certso ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'subject.organization');
-   return $self->asd('post', '/asd/domain/certso', $param, { certso => $arg }, $cb, $cb_args);
-}
-
-sub asd_dns_domain_exist ($self, $arg, $param = undef, $cb = undef, $cb_args = undef) {
-   $arg = $self->_load_file($arg);
-   $arg = $self->_arg_from_field($arg, 'domain');
-   return $self->asd('post', '/asd/dns/domain/exist', $param, { domain => $arg }, $cb, $cb_args);
-}
-
-sub asd_task_id ($self, $taskid, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->asd('get', '/asd/task/id/'.$taskid, $param, undef, $cb, $cb_args);
-}
-
-sub asd_task_poll ($self, $taskid, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->asd('get', '/asd/task/poll/'.$taskid, $param, undef, $cb, $cb_args);
-}
-
-sub asd_task_list ($self, $taskid, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->asd('get', '/asd/task/list', $param, undef, $cb, $cb_args);
-}
-
-sub asd_task_kill ($self, $taskid, $param = undef, $cb = undef, $cb_args = undef) {
-   return $self->asd('delete', '/asd/task/kill/'.$taskid, $param, undef, $cb, $cb_args);
-}
-
-sub asd_load_input ($self, $input) {
-   my $docs = [];
-   my @lines = read_file($input);
-   for (@lines) {
-      chomp;
-      unless ($_ =~ m{[=:]}) {  # Need a key:value pair
-         print STDERR "ERROR: asd_loas_input: invalid line found[$_], skipping\n";
-         next;
-      }
-      s{(?:^\s*|\s*)$}{}g;
-      #utf8::encode($line);  # Not required, already in UTF-8
-      my ($k, $v) = split(/\s*[=:]\s*/, $_, 2);
-      next unless (defined($k) && defined($v));
-      $v =~ s{(?:^["']|["']$)}{}g;
-      push @$docs, { $k => $v };
-   }
-
-   print STDERR "VERBOSE: loaded ASD file: $input: ".Data::Dumper::Dumper($docs)."\n"
-      if $self->verbose;
-
-   return $docs;
-}
-
 1;
 
 __END__
@@ -1171,7 +776,7 @@ Onyphe::Api - ONYPHE API
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2025, ONYPHE SAS
+Copyright (c) 2023, ONYPHE
 
 You may distribute this module under the terms of The BSD 3-Clause License.
 See LICENSE file in the source distribution archive.
